@@ -48,6 +48,7 @@ CLUSTER_ATTRIBUTES = [
     'create_timeout',
     'node_count',
     'discovery_url',
+    'docker_volume_size',
     'master_count',
     'container_version',
     'name',
@@ -84,7 +85,7 @@ class CreateCluster(command.Command):
         parser.add_argument('--labels',
                             metavar='<KEY1=VALUE1,KEY2=VALUE2;KEY3=VALUE3...>',
                             action='append',
-                            help=_('Arbitrary labels in the form of key=value'
+                            help=_('Arbitrary labels in the form of key=value '
                                    'pairs to associate with a cluster '
                                    'template. May be used multiple times.'))
         parser.add_argument('--keypair',
@@ -158,10 +159,16 @@ class CreateCluster(command.Command):
         parser.add_argument(
             '--master-lb-enabled',
             dest='master_lb_enabled',
-            action='store_true',
-            default=False,
-            help=_('Indicates whether created clusters should have '
-                   'a loadbalancer for API.'))
+            action='append_const',
+            default=[],
+            const=True,
+            help=_('Enable master LB creation on the new cluster'))
+        parser.add_argument(
+            '--master-lb-disabled',
+            dest='master_lb_enabled',
+            action='append_const',
+            const=False,
+            help=_('Disable master LB creation on the new cluster'))
 
         return parser
 
@@ -214,6 +221,20 @@ class CreateCluster(command.Command):
         if parsed_args.master_lb_enabled:
             args["master_lb_enabled"] = parsed_args.master_lb_enabled
 
+        if len(parsed_args.master_lb_enabled) > 1:
+            raise exceptions.InvalidAttribute(
+                '--master-lb-enabled and '
+                '--master-lb-disabled are '
+                'mutually exclusive and '
+                'should be specified only once.')
+        elif len(parsed_args.master_lb_enabled) == 1:
+            args['master_lb_enabled'] = parsed_args.master_lb_enabled[0]
+            if (not args['master_lb_enabled'] and
+                    parsed_args.master_count > 1):
+                raise exceptions.InvalidAttribute(
+                    'Master node count can only be one if master '
+                    'loadbalancer is disabled.')
+
         cluster = mag_client.clusters.create(**args)
         print("Request to create cluster %s accepted"
               % cluster.uuid)
@@ -417,30 +438,63 @@ class ConfigCluster(command.Command):
 
         cluster_template = mag_client.cluster_templates.get(
             cluster.cluster_template_id)
-        opts = {
-            'cluster_uuid': cluster.uuid,
-        }
 
-        tls = None
-        if not cluster_template.tls_disabled:
-            tls = magnum_utils.generate_csr_and_key()
-            tls['ca'] = mag_client.certificates.get(**opts).pem
-            opts['csr'] = tls['csr']
-            tls['cert'] = mag_client.certificates.create(**opts).pem
-            if parsed_args.output_certs:
-                for k in ('key', 'cert', 'ca'):
-                    fname = "%s/%s.pem" % (parsed_args.dir, k)
-                    if os.path.exists(fname) and not parsed_args.force:
-                        raise Exception("File %s exists, aborting." % fname)
-                    else:
-                        with open(fname, "w") as f:
-                            f.write(tls[k])
+        tls = self._fetch_tls(
+            mag_client=mag_client,
+            cluster_uuid=cluster.uuid,
+            tls_required=(not cluster_template.tls_disabled),
+            certkey_required=(not parsed_args.use_keystone)
+        )
+
+        if parsed_args.output_certs:
+            self._write_certs(
+                certs=tls,
+                path=parsed_args.dir,
+                force=parsed_args.force
+            )
 
         print(magnum_utils.config_cluster(
             cluster, cluster_template, parsed_args.dir,
             force=parsed_args.force, certs=tls,
             use_keystone=parsed_args.use_keystone))
 
+    def _fetch_tls(
+            self,
+            mag_client,
+            cluster_uuid,
+            tls_required,
+            certkey_required=True,
+    ):
+        if not tls_required:
+            return {}
+        opts = {
+            'cluster_uuid': cluster_uuid,
+        }
+        tls = {
+            'ca': mag_client.certificates.get(**opts).pem
+        }
+
+        if certkey_required:
+            csr = magnum_utils.generate_csr_and_key()
+            opts['csr'] = csr['csr']
+            tls['cert'] = mag_client.certificates.create(**opts).pem
+            tls['key'] = csr['key']
+        return tls
+
+    def _write_certs(self, certs, path, force):
+        for k in ('key', 'cert', 'ca'):
+            fname = "%s/%s.pem" % (path, k)
+            if os.path.exists(fname):
+                if not force:
+                    raise Exception("File %s exists, aborting." % fname)
+                os.remove(fname)
+
+            if k not in certs:
+                # key and cert aren't always generated
+                continue
+            with open(fname, "w") as f:
+                f.write(certs[k])
+
 
 class ResizeCluster(command.Command):
     _description = _("Resize a Cluster")
@@ -461,8 +515,8 @@ class ResizeCluster(command.Command):
             '--nodes-to-remove',
             metavar='<Server UUID>',
             action='append',
-            help=_("Server ID of the nodes to be removed. Repeat to add"
-                   "more server ID"))
+            help=_('Server ID of the nodes to be removed. Repeat to add '
+                   'more server ID'))
 
         parser.add_argument(
             '--nodegroup',
