@@ -21,8 +21,6 @@
 """
 Command-line interface to the OpenStack Magnum API.
 """
-
-from __future__ import print_function
 import argparse
 import logging
 import os
@@ -31,7 +29,13 @@ import sys
 from oslo_utils import encodeutils
 from oslo_utils import importutils
 from oslo_utils import strutils
-import six
+
+from magnumclient.common import cliutils
+from magnumclient import exceptions as exc
+from magnumclient.i18n import _
+from magnumclient.v1 import client as client_v1
+from magnumclient.v1 import shell as shell_v1
+from magnumclient import version
 
 profiler = importutils.try_import("osprofiler.profiler")
 
@@ -51,12 +55,6 @@ try:
 except ImportError:
     pass
 
-from magnumclient.common import cliutils
-from magnumclient import exceptions as exc
-from magnumclient.i18n import _
-from magnumclient.v1 import client as client_v1
-from magnumclient.v1 import shell as shell_v1
-from magnumclient import version
 
 LATEST_API_VERSION = ('1', 'latest')
 DEFAULT_INTERFACE = 'public'
@@ -641,7 +639,7 @@ def main():
 
     except Exception as e:
         logger.debug(e, exc_info=1)
-        print("ERROR: %s" % encodeutils.safe_encode(six.text_type(e)),
+        print("ERROR: %s" % encodeutils.safe_encode(str(e)),
               file=sys.stderr)
         sys.exit(1)
 
