@@ -185,7 +185,9 @@ class FakeClusterTemplate(object):
             'flavor_id': 'm1.medium',
             'master_lb_enabled': False,
             'dns_nameserver': '8.8.8.8',
-            'hidden': False
+            'project_id': uuid.uuid4().hex,
+            'hidden': False,
+            'tags': "",
         }
 
         # Overwrite default attributes.
@@ -253,6 +255,7 @@ class FakeCluster(object):
             'create_timeout': 60,
             'node_count': 1,
             'discovery_url': 'https://fake.cluster',
+            'docker_volume_size': 1,
             'master_count': 1,
             'container_version': None,
             'name': 'fake-cluster',
